@@ -11,10 +11,16 @@ Music = {
     searchOptions: {},
     infiniteScrollActive: false,
     sessionPing: 60000,
+    remaining: 0,
     csrf_token: null,
 
     init: function() {
-        Music.csrf_token = $('#csrf_token input').val();
+        Music.csrf_token = $('#csrf_token input[name="csrfmiddlewaretoken"]').val();
+        jQuery.ajaxSetup({
+            headers: {
+                'X-CSRFToken': Music.csrf_token
+            }
+        });
 
         $(".loadList").bind("click", function() {
             Music.options = {};
@@ -219,8 +225,7 @@ Music = {
                 url: "/api/v1/queue",
                 type: "POST",
                 data: {
-                    "id": $(this).attr("data-id"),
-                    "csrfmiddlewaretoken": Music.csrf_token
+                    "id": $(this).attr("data-id")
                 },
                 success: function(data) {
                     var item = $("img.queue_add[data-id=" + data.id + "]");
@@ -244,7 +249,6 @@ Music = {
                     item.attr("src", "/static/img/queue.png");
                     item.removeClass("queue_remove");
                     item.addClass("queue_add");
-                    item.attr("id", item.attr("id").replace(/remove/, "add"));
                     item.attr("alt", gettext("Vote to play"));
                     item.attr("title", gettext("Vote to play"));
                 };
@@ -262,7 +266,6 @@ Music = {
                     item.attr("src", "/static/img/queue.png");
                     item.removeClass("queue_remove");
                     item.addClass("queue_add");
-                    item.attr("id", item.attr("id").replace(/remove/, "add"));
                     item.attr("alt", gettext("Support vote"));
                     item.attr("title", gettext("Support vote"));
                     item.closest("tr").find(".voteCount").html(data.count);
@@ -284,15 +287,13 @@ Music = {
                 url: "/api/v1/favourites",
                 type: "POST",
                 data: {
-                    "id": $(this).attr("data-id"),
-                    "csrfmiddlewaretoken": Music.csrf_token
+                    "id": $(this).attr("data-id")
                 },
                 success: function(data) {
                     var item = $("img.favourite_add[data-id=" + data.id + "]");
                     item.attr("src", "/static/img/favourite_active.png");
                     item.removeClass("favourite_add");
                     item.addClass("favourite_remove");
-                    item.attr("id", item.attr("id").replace(/add/, "remove"));
                     item.attr("alt", gettext("Remove from favourites"));
                     item.attr("title", gettext("Remove from favourites"));
                 }
@@ -308,7 +309,6 @@ Music = {
                     item.attr("src", "/static/img/favourite.png");
                     item.removeClass("favourite_remove");
                     item.addClass("favourite_add");
-                    item.attr("id", item.attr("id").replace(/remove/, "add"));
                     item.attr("alt", gettext("Add to favourites"));
                     item.attr("title", gettext("Add to favourites"));
                 };
@@ -356,8 +356,8 @@ Music = {
             dataType: "json"
         });
 
-        setTimeout("Music.ping()", Music.sessionPing);
-
+        Music.getCurrentSong();
+        Music.ping();
         Music.loadList("/api/v1/queue");
         Music.setActiveMenu($("#sidebar ul li a.loadQueue"));
     },
@@ -371,6 +371,43 @@ Music = {
         });
     },
 
+    getCurrentSong: function() {
+         $.ajax({
+            url: "/api/v1/songs/current",
+            success: function(data) {
+                if ("id" in data) {
+                    $('#currentSong strong').show();
+                    $('#currentSong span.songTitle').html(data.artist.name + " - " + data.title);
+                    Music.remaining = data.remaining;
+                    Music.updateTimeLeft();
+                }
+                else {
+                    $('#currentSong strong').hide();
+                }
+            }
+        });
+    },
+
+    updateTimeLeft: function() {
+        if (0 == Music.remaining) {
+            $('#currentSong span.timeRemaining').hide();
+            setTimeout("Music.getCurrentSong()", 1000);
+            return;
+        }
+        else if (Music.remaining > 0) {
+            var minutes = parseInt(Music.remaining / 60);
+            var secondsInt = Music.remaining % 60;
+            var seconds = secondsInt.toString();
+            if (secondsInt < 10) {
+                seconds = "0" + seconds;
+            }
+            $('#currentSong span.timeRemaining').show();
+            $('#currentSong span.timeRemaining').html("(" + minutes + ":" + seconds + ")");
+            Music.remaining--;
+        }
+        setTimeout("Music.updateTimeLeft()", 1000);
+    },
+
     getSearchOptions: function() {
         var options = {};
 
